template: contact

another link | another link | another link | another link

# ORANGE_SUNSET

# latest news

## 01.09.2006

This is where you can put your latest news.

read more ...

## 01.09.2006

This is where you can put your latest news.

read more ...

# additional links

- open designs
- learn XHTML
- learn CSS
- get firefox

# other information

This space can be used for additional information such as a contact phone number, address or maybe even a graphic.

# contact

Below is an example of how a contact form might look with this template:

your name
your email address
your enquiry

NOTE: A contact form such as this would require some way of emailing the input to a specified email address.